@@ -2,15 +2,15 @@
 // Licensed under the MIT license http://opensource.org/licenses/MIT
 //port from https://github.com/seanmonstar/warp/blob/master/examples/sse.rs
 
-use futures::StreamExt;
-use salvo::prelude::*;
 use std::convert::Infallible;
 use std::time::Duration;
+
+use futures_util::StreamExt;
+use salvo::prelude::*;
+use salvo_extra::sse::{self, SseEvent};
 use tokio::time::interval;
 use tokio_stream::wrappers::IntervalStream;
 
-use salvo_extra::sse::{self, SseEvent};
-
 // create server-sent event
 fn sse_counter(counter: u64) -> Result<SseEvent, Infallible> {
     Ok(SseEvent::default().data(counter.to_string()))
@@ -35,6 +35,6 @@ async fn handle_tick(_req: &mut Request, res: &mut Response) {
 async fn main() {
     tracing_subscriber::fmt().init();
 
-    let router = Router::new().path("ticks").get(handle_tick);
+    let router = Router::with_path("ticks").get(handle_tick);
     Server::new(router).bind(([0, 0, 0, 0], 7878)).await;
 }
