@@ -7,8 +7,7 @@ use std::collections::HashMap;
 use std::sync::atomic::{AtomicUsize, Ordering};
 use std::sync::Mutex;
 
-use futures;
-use futures::StreamExt;
+use futures_util::StreamExt;
 use once_cell::sync::Lazy;
 use tokio::sync::mpsc;
 use tokio_stream::wrappers::UnboundedReceiverStream;
@@ -26,10 +25,9 @@ async fn main() {
     tracing_subscriber::fmt().init();
 
     let router = Router::new().handle(index).push(
-        Router::new()
-            .path("chat")
+        Router::with_path("chat")
             .get(user_connected)
-            .push(Router::new().path("<id>").post(chat_send)),
+            .push(Router::with_path("<id>").post(chat_send)),
     );
     Server::new(router).bind(([0, 0, 0, 0], 3232)).await;
 }
